@@ -17,8 +17,8 @@ print __doc__
 import numpy as np
 import pylab as pl
 
-from scikits.learn import linear_model
-from scikits.learn import datasets
+from sklearn import linear_model
+from sklearn import datasets
 
 diabetes = datasets.load_diabetes()
 X = diabetes.data
