@@ -16,9 +16,9 @@ from datetime import datetime
 import numpy as np
 import pylab as pl
 
-from scikits.learn import linear_model
-from scikits.learn import datasets
-from scikits.learn.svm import l1_min_c
+from sklearn import linear_model
+from sklearn import datasets
+from sklearn.svm import l1_min_c
 
 iris = datasets.load_iris()
 X = iris.data
@@ -38,7 +38,11 @@ cs = l1_min_c(X, y, loss='log') * np.logspace(0, 3)
 print "Computing regularization path ..."
 start = datetime.now()
 clf = linear_model.LogisticRegression(C=1.0, penalty='l1', tol=1e-6)
-coefs_ = [clf.fit(X, y, C=c).coef_.ravel().copy() for c in cs]
+coefs_ = []
+for c in cs:
+    clf.set_params(C=c)
+    clf.fit(X, y)
+    coefs_.append(clf.coef_.ravel().copy())
 print "This took ", datetime.now() - start
 
 coefs_ = np.array(coefs_)
