@@ -11,7 +11,7 @@ print __doc__
 
 import numpy as np
 import pylab as pl
-from scikits.learn import svm, datasets
+from sklearn import svm, datasets
 
 # import some data to play with
 iris = datasets.load_iris()
