@@ -14,7 +14,7 @@ print __doc__
 
 import numpy as np
 import pylab as pl
-from scikits.learn import svm
+from sklearn import svm
 
 # we create 40 separable points
 np.random.seed(0)
