@@ -10,8 +10,8 @@ print __doc__
 
 import numpy as np
 import pylab as pl
-from scikits.learn import svm, datasets, feature_selection, cross_val
-from scikits.learn.pipeline import Pipeline
+from sklearn import svm, datasets, feature_selection, cross_validation
+from sklearn.pipeline import Pipeline
 
 ################################################################################
 # Import some data to play with
@@ -40,9 +40,9 @@ score_stds  = list()
 percentiles = (1, 3, 6, 10, 15, 20, 30, 40, 60, 80, 100)
 
 for percentile in percentiles:
-    clf._set_params(anova__percentile=percentile)
+    clf.set_params(anova__percentile=percentile)
     # Compute cross-validation score using all CPUs
-    this_scores = cross_val.cross_val_score(clf, X, y, n_jobs=1)
+    this_scores = cross_validation.cross_val_score(clf, X, y, n_jobs=1)
     score_means.append(this_scores.mean())
     score_stds.append(this_scores.std())
 
